Crate omg_idl_code_gen

Crate omg_idl_code_gen 

Structs

Configuration
Container for where to find a file and if extra logging occur

Enums

IdlError

Traits

IdlLoader
All IDL Loader must be capable of reading data into the system

Functions

generate_with_search_path
Provided w/ an object that supports writing and a OMG Gen Config generate Rust Types for the requested OMG IDL files.