Structs
- Configuration
- Container for where to find a file and if extra logging occur
Enums
Traits
- IdlLoader
- All IDL Loader must be capable of reading data into the system
Functions
- generate_
with_ search_ path - Provided w/ an object that supports writing and a OMG Gen Config generate Rust Types for the requested OMG IDL files.